diff --git a/Documentation/NuttxPortingGuide.html b/Documentation/NuttxPortingGuide.html
index 967689e97ec..dedb90c32ce 100644
--- a/Documentation/NuttxPortingGuide.html
+++ b/Documentation/NuttxPortingGuide.html
@@ -159,7 +159,7 @@
4.7.2 OS List Management APIs
4.7.3 nxsched_process_timer()
4.7.4 nxsched_timer_expiration()
- 4.7.5 sched_alarm_expiration()
+ 4.7.5 nxsched_alarm_expiration()
4.7.6 irq_dispatch()
4.8 Application OS vs. Internal OS Interfaces
@@ -2650,7 +2650,7 @@ config ARCH_SIM
sched_alarm_expiration(). Called by the platform-specific logic when the alarm expires.
+ nxsched_alarm_expiration(). Called by the platform-specific logic when the alarm expires.
nxsched_timer_expiration(). Called by the platform-specific logic when the interval time expires.
@@ -3983,7 +3983,7 @@ void nxsched_timer_expiration(void);
Base code implementation assumes that this function is called from interrupt handling logic with interrupts disabled.
sched_alarm_expiration()nxsched_alarm_expiration()Function Prototype:
#include <nuttx/arch.h>
diff --git a/arch/arm/src/lpc43xx/lpc43_rit.c b/arch/arm/src/lpc43xx/lpc43_rit.c
index c39e4b7a383..b538cbbf0e1 100644
--- a/arch/arm/src/lpc43xx/lpc43_rit.c
+++ b/arch/arm/src/lpc43xx/lpc43_rit.c
@@ -101,7 +101,7 @@ static int lpc43_RIT_isr(int irq, FAR void *context, FAR void *arg)
g_ts.tv_sec = (uint32_t)(internal_timer / 1000000000);
g_ts.tv_nsec = (uint32_t)(internal_timer % 1000000000);
- sched_alarm_expiration(&g_ts);
+ nxsched_alarm_expiration(&g_ts);
}
leave_critical_section(flags);
diff --git a/arch/arm/src/lpc43xx/lpc43_tickless_rit.c b/arch/arm/src/lpc43xx/lpc43_tickless_rit.c
index c029a9a0fab..17f657ee876 100644
--- a/arch/arm/src/lpc43xx/lpc43_tickless_rit.c
+++ b/arch/arm/src/lpc43xx/lpc43_tickless_rit.c
@@ -528,7 +528,7 @@ static inline void lpc43_tl_alarm(uint32_t curr)
#ifdef CONFIG_SCHED_TICKLESS_ALARM
struct timespec ts;
up_timer_gettime(&ts);
- sched_alarm_expiration(&ts);
+ nxsched_alarm_expiration(&ts);
#else
nxsched_timer_expiration();
#endif
diff --git a/arch/arm/src/lpc54xx/lpc54_tickless.c b/arch/arm/src/lpc54xx/lpc54_tickless.c
index 62192dff97d..69ef5d2f301 100644
--- a/arch/arm/src/lpc54xx/lpc54_tickless.c
+++ b/arch/arm/src/lpc54xx/lpc54_tickless.c
@@ -558,7 +558,7 @@ static inline void lpc54_tl_alarm(uint64_t curr)
#ifdef CONFIG_SCHED_TICKLESS_ALARM
struct timespec ts;
up_timer_gettime(&ts);
- sched_alarm_expiration(&ts);
+ nxsched_alarm_expiration(&ts);
#else
nxsched_timer_expiration();
#endif
diff --git a/sched/sched/sched_timerexpiration.c b/sched/sched/sched_timerexpiration.c
index 4a0a13b432d..c60f98062eb 100644
--- a/sched/sched/sched_timerexpiration.c
+++ b/sched/sched/sched_timerexpiration.c
@@ -465,7 +465,7 @@ static void nxsched_timer_start(unsigned int ticks)
****************************************************************************/
/****************************************************************************
- * Name: sched_alarm_expiration
+ * Name: nxsched_alarm_expiration
*
* Description:
* if CONFIG_SCHED_TICKLESS is defined, then this function is provided by
@@ -485,7 +485,7 @@ static void nxsched_timer_start(unsigned int ticks)
****************************************************************************/
#ifdef CONFIG_SCHED_TICKLESS_ALARM
-void sched_alarm_expiration(FAR const struct timespec *ts)
+void nxsched_alarm_expiration(FAR const struct timespec *ts)
{
unsigned int elapsed;
unsigned int nexttime;
diff --git a/drivers/timers/arch_alarm.c b/drivers/timers/arch_alarm.c
index d0ad56bfbd5..9f8d9535d8f 100644
--- a/drivers/timers/arch_alarm.c
+++ b/drivers/timers/arch_alarm.c
@@ -167,7 +167,7 @@ static void oneshot_callback(FAR struct oneshot_lowerhalf_s *lower,
#ifdef CONFIG_SCHED_TICKLESS
ONESHOT_CURRENT(g_oneshot_lower, &now);
- sched_alarm_expiration(&now);
+ nxsched_alarm_expiration(&now);
#else
struct timespec delta;
@@ -306,7 +306,7 @@ int up_timer_gettime(FAR struct timespec *ts)
* Description:
* Cancel the alarm and return the time of cancellation of the alarm.
* These two steps need to be as nearly atomic as possible.
* sched_alarm_expiration() will not be called unless the alarm is
* restarted with up_alarm_start().
*
* If, as a race condition, the alarm has already expired when this
@@ -353,14 +353,14 @@ int up_alarm_cancel(FAR struct timespec *ts)
* Name: up_alarm_start
*
* Description:
* Start the alarm. sched_alarm_expiration() will be called when the
* alarm occurs (unless up_alaram_cancel is called to stop it).
*
* Provided by platform-specific code and called from the RTOS base code.
*
* Input Parameters:
* ts - The time in the future at the alarm is expected to occur. When
* the alarm occurs the timer logic will call sched_alarm_expiration().
*
* Returned Value:
* Zero (OK) is returned on success; a negated errno value is returned on
@@ -306,7 +306,7 @@ int up_timer_gettime(FAR struct timespec *ts)
* Cancel the alarm and return the time of cancellation of the alarm.
* These two steps need to be as nearly atomic as possible.
- * sched_alarm_expiration() will not be called unless the alarm is
+ * nxsched_alarm_expiration() will not be called unless the alarm is
* restarted with up_alarm_start().
*
@@ -353,14 +353,14 @@ int up_alarm_cancel(FAR struct timespec *ts)
*
* Description:
- * Start the alarm. sched_alarm_expiration() will be called when the
+ * Start the alarm. nxsched_alarm_expiration() will be called when the
* alarm occurs (unless up_alaram_cancel is called to stop it).
*
@@ -353,14 +353,14 @@ int up_alarm_cancel(FAR struct timespec *ts)
* Input Parameters:
* ts - The time in the future at the alarm is expected to occur. When
- * the alarm occurs the timer logic will call sched_alarm_expiration().
+ * the alarm occurs the timer logic will call nxsched_alarm_expiration().
*
* Returned Value:
diff --git a/include/nuttx/arch.h b/include/nuttx/arch.h
index 0cc0e858b3c..49b8bc77cb9 100644
--- a/include/nuttx/arch.h
+++ b/include/nuttx/arch.h
@@ -1431,7 +1431,7 @@ int up_prioritize_irq(int irq, int priority);
* specific interval timer implementation:
*
* #ifdef CONFIG_SCHED_TICKLESS_ALARM
* void sched_alarm_expiration(FAR const struct timespec *ts): Called
* by the platform-specific logic when the alarm expires.
* #else
* void nxsched_timer_expiration(void): Called by the platform-specific
@@ -1488,7 +1488,7 @@ void up_timer_getmask(FAR uint64_t *mask);
* Description:
* Cancel the alarm and return the time of cancellation of the alarm.
* These two steps need to be as nearly atomic as possible.
* sched_alarm_expiration() will not be called unless the alarm is
* restarted with up_alarm_start().
*
* If, as a race condition, the alarm has already expired when this
@@ -1524,14 +1524,14 @@ int up_alarm_cancel(FAR struct timespec *ts);
* Name: up_alarm_start
*
* Description:
* Start the alarm. sched_alarm_expiration() will be called when the
* alarm occurs (unless up_alaram_cancel is called to stop it).
*
* Provided by platform-specific code and called from the RTOS base code.
*
* Input Parameters:
* ts - The time in the future at the alarm is expected to occur. When
* the alarm occurs the timer logic will call sched_alarm_expiration().
*
* Returned Value:
* Zero (OK) is returned on success; a negated errno value is returned on
@@ -2030,7 +2030,7 @@ void nxsched_timer_expiration(void);
#endif
/****************************************************************************
- * Name: sched_alarm_expiration
+ * Name: nxsched_alarm_expiration
*
* Description:
* if CONFIG_SCHED_TICKLESS is defined, then this function is provided by
@@ -2050,7 +2050,7 @@ void nxsched_timer_expiration(void);
****************************************************************************/
#if defined(CONFIG_SCHED_TICKLESS) && defined(CONFIG_SCHED_TICKLESS_ALARM)
-void sched_alarm_expiration(FAR const struct timespec *ts);
+void nxsched_alarm_expiration(FAR const struct timespec *ts);
#endif
/****************************************************************************
@@ -1431,7 +1431,7 @@ int up_prioritize_irq(int irq, int priority);
*
* #ifdef CONFIG_SCHED_TICKLESS_ALARM
- * void sched_alarm_expiration(FAR const struct timespec *ts): Called
+ * void nxsched_alarm_expiration(FAR const struct timespec *ts): Called
* by the platform-specific logic when the alarm expires.
* #else
@@ -1488,7 +1488,7 @@ void up_timer_getmask(FAR uint64_t *mask);
* Cancel the alarm and return the time of cancellation of the alarm.
* These two steps need to be as nearly atomic as possible.
- * sched_alarm_expiration() will not be called unless the alarm is
+ * nxsched_alarm_expiration() will not be called unless the alarm is
* restarted with up_alarm_start().
*
@@ -1524,14 +1524,14 @@ int up_alarm_cancel(FAR struct timespec *ts);
*
* Description:
- * Start the alarm. sched_alarm_expiration() will be called when the
+ * Start the alarm. nxsched_alarm_expiration() will be called when the
* alarm occurs (unless up_alaram_cancel is called to stop it).
*
@@ -1524,14 +1524,14 @@ int up_alarm_cancel(FAR struct timespec *ts);
* Input Parameters:
* ts - The time in the future at the alarm is expected to occur. When
- * the alarm occurs the timer logic will call sched_alarm_expiration().
+ * the alarm occurs the timer logic will call nxsched_alarm_expiration().
*
* Returned Value: